// Craig S. Kaplan
// Use CSV files containing baseball statistics to find out
// the ten highest salaries received by baseball players in
// one year.

StringDict player_dict;

void setup()
{
  // First, load in the table containing the biographical information
  // about baseball players.  Use that to build a Dictionary mapping
  // PlayerIDs (sort of like your WatIAM student ID) to full names
  // (so that we can report the information nicely).

  Table master = loadTable( "Master.csv", "header" );
  player_dict = new StringDict();
  for ( int idx = 0; idx < master.getRowCount(); ++idx ) {
    // Associate the given key with the player's full name.
    player_dict.set( master.getString( idx, "playerID" ), 
      master.getString( idx, "nameFirst" ) + " " + 
      master.getString( idx, "nameLast" ) );
  }
  
  // Now load in the salaries table...
  Table sals = loadTable( "Salaries.csv", "header" );
  // ...and sort it in decending order by salary.  That pushes
  // the top salaries to the first rows of the table.
  
  // By default, Processing will assume that a field is text, and
  // sort using alphabetical order.  But that's not necessarily
  // what you want.  In this case, ten million a year will appear
  // to be *less* than nine million, because "10000000" comes
  // alphabetically before "9000000".  The following line is not
  // at all obvious (I had to look it up deep inside the guts of
  // Processing), but it solves the problem with one line of code.
  // It forces the table to think of the elements in this column
  // as integers when sorting them.
  sals.setColumnType( "salary", Table.INT );
  
  // OK, *now* it's safe to sort salaries by treating them as plain
  // old numbers.
  sals.sortReverse( "salary" );
  
  // Walk over the first ten rows, reporting on player names and
  // their salaries.
  for( int idx = 0; idx < 10; ++idx ) {
    String name = player_dict.get( sals.getString( idx, "playerID" ) );
    println( name + " (" + sals.getString( idx, "yearID" ) + "): "
		+ sals.getString( idx, "salary" ) );
  }
}