// Craig S. Kaplan
// A more elaborate sketch based on baseball stats.  Ask the
// user for a team name and a year.  Find the list of all players
// from that team and year, and display their names in the sketch
// window.

// Information about teams (including the team's ID and its full name)
Table teams;
// Information about every player's appearance in a given team in a 
// given year.
Table appearances;
// Dictionary mapping a player's magic ID to their name.
StringDict player_dict;

// ControlP5 user interface...

import controlP5.*;

ControlP5 ui;
Textfield year;
Textfield team;
Textarea players;

void setup()
{
  size( 550, 500 );

  ui = new ControlP5( this );

  PFont fnt = createFont( "Arial", 24 );

  year = ui.addTextfield( "Year" )
    .setSize( 100, 40 )
    .setFont( fnt )
    .setPosition( 10, 10 )
    .setAutoClear( false );
  team = ui.addTextfield( "Team" )
    .setSize( 200, 40 )
    .setFont( fnt )
    .setPosition( 120, 10 )
    .setAutoClear( false );

  players = ui.addTextarea( "Players" )
    .setSize( 500, 380 )
    .setPosition( 10, 100 )
    .setFont( fnt )
    .setColor( color( 0 ) );

  teams = loadTable( "Teams.csv", "header" );
  appearances = loadTable( "Appearances.csv", "header" );

  // As in the BaseballSalaries sketch, load in the biographical
  // table and build a dictionary mapping a player's ID to their
  // full name.
  
  Table master = loadTable( "Master.csv", "header" );
  player_dict = new StringDict();
  for ( int idx = 0; idx < master.getRowCount(); ++idx ) {
    player_dict.set( master.getString( idx, "playerID" ), 
      master.getString( idx, "nameFirst" ) + " " + 
      master.getString( idx, "nameLast" ) );
  }
}

void draw()
{
  background( 240 );
}

void controlEvent( ControlEvent ce )
{
  String yr = year.getText();
  String tm = team.getText();

  if ( yr.length() == 0 || tm.length() == 0 ) {
    return;
  }

  String team_id = null;

  for ( int idx = 0; idx < teams.getRowCount(); ++idx ) {
    String a_team = teams.getString( idx, "name" );
    String a_year = teams.getString( idx, "yearID" );

    // Oh hey, the text the user typed in was found inside the
    // team name in the teams table.  That's probably the team
    // they're interested in, so set aside this teamID.
    
    if ( a_team.contains( tm ) && a_year.equals( yr ) ) {
      //println( teams.getString( idx, "teamID" ) );
      team_id = teams.getString( idx, "teamID" );
      break;
    }
  }

  String[] names = {};
  
  // Find all the players associated with that teamID.  For each
  // one, get their full name.
  
  if ( team_id != null ) {
    for ( int idx = 0; idx < appearances.getRowCount(); ++idx ) {
      String a_team_id = appearances.getString( idx, "teamID" );
      String a_year = appearances.getString( idx, "yearID" );
      if ( a_year.equals( yr ) && a_team_id.equals( team_id ) ) {
        String a_player = appearances.getString( idx, "playerID" );
        names = append( names, player_dict.get( a_player ) );
      }
    }
  }
  
  players.setText( join( names, "\n" ) );
}