// Craig S. Kaplan

// Read in the three tables associated with food
// safety inspections in the Region of Waterloo, and
// provide an interface in which you can type in all
// or part of a restaurant's name and see a list of all
// its infractions in the past year.  A complicated sketch
// that relies on the interaction between three tables.

// Be careful playing with the sketch -- you might learn
// more about local restaurants than you wanted to know.

import controlP5.*;

// The three tables provided by the region of
// Waterloo.
Table facilities;
Table inspections;
Table infractions;

ControlP5 cp5;
Textfield txt;
Textarea num;
Textarea infs;

void setup()
{
  size( 800, 600 );
  cp5 = new ControlP5( this );
  PFont fnt = createFont( "Helvetica", 24 );
  ControlFont cfnt = new ControlFont( fnt );
  
  txt = cp5.addTextfield( "Location" )
    .setPosition( 50, 50 )
    .setSize( 300, 30 )
    .setFont( cfnt );
  num = cp5.addTextarea( "Total" )
    .hideScrollbar()
    .setPosition( 400, 50 )
    .setSize( 150, 30 )
    .setFont( cfnt );
  infs = cp5.addTextarea( "Infractions" )
    .setPosition( 50, 125 )
    .setSize( 700, 450 )
    .setFont( cfnt );

  facilities = loadTable( "Facilities_OpenData.csv", "header" );
  inspections = loadTable( "Inspections_OpenData.csv", "header" );
  infractions = loadTable( "Infractions_OpenData.csv", "header" );

  background( 0 );
  fill( 255 );
}

void draw()
{
  background( 0 );
}

// Search the list of facilities for the first one
// that matches the passed-in name.  Return the
// associated FACILITYID code.
String getFacilityId( String name )
{
  name = name.toLowerCase();
  for ( int idx = 0; idx < facilities.getRowCount (); ++idx ) {
    String a_name = facilities.getString( idx, "BUSINESS_NAME" ).toLowerCase();
    if ( a_name.contains( name ) ) {
      return facilities.getString( idx, "FACILITYID" );
    }
  }
  return null;
}

// Get a list of all codes of inspections associated
// with a given FACILITYID.
String[] getInspections( String id )
{
  String[] ret = new String[0];

  for ( int idx = 0; idx < inspections.getRowCount (); ++idx ) {
    if ( id.equals( inspections.getString( idx, "FACILITYID" ) ) ) {
      ret = append( ret, inspections.getString( idx, "INSPECTION_ID" ) );
      ret = append( ret, inspections.getString( idx, "INSPECTION_DATE" ) );
    }
  }

  return ret;
}

// Get a list of all infractions associated with
// a given inspection.
String[] getInfractions( String iid, String date )
{
  String[] ret = new String[0];

  for ( int idx = 0; idx < infractions.getRowCount(); ++idx ) {
    if ( iid.equals( infractions.getString( idx, "INSPECTION_ID" ) ) ) {
      ret = append( ret, 
        "[" + date + "]: " + infractions.getString( idx, "Infraction" ) );
    }
  }

  return ret;
}

void controlEvent( ControlEvent ce )
{
  num.clear();
  infs.clear();

  String name = txt.getText().toLowerCase();
  String id = getFacilityId( name );

  if ( id == null ) {
    infs.setText( "No such restaurant" );
    return;
  }
  
  for( int idx = 0; idx < facilities.getRowCount(); ++idx ) {
    if( facilities.getString( idx, "FACILITYID" ).equals( id ) ) {
      String bname = facilities.getString( idx, "BUSINESS_NAME" );
      String addr = facilities.getString( idx, "ADDR" );
      infs.append( bname + "\n" );
      infs.append( addr + "\n\n" );
      break;
    }
  }

  String[] inss = getInspections( id );
  String[] all_infs = new String[0];

  for ( int idx = 0; idx < inss.length; idx += 2 ) {
    all_infs = concat( all_infs, getInfractions( inss[idx], inss[idx+1] ) );
  } 

  if ( all_infs.length == 0 ) {
    infs.append( "No infractions." );
  } else {
    String report = "";
    for ( int idx = 0; idx < all_infs.length; ++idx ) {
      infs.append( "* " + all_infs[idx] + "\n" );
    }    
    num.setText( "Total: " + all_infs.length );
  }
}