// Craig S. Kaplan
// 
// Show how you can actually visualize tabular data in the style
// of a spreadsheet by iterating over all the cells and drawing
// text to the sketch window in a grid.  Support using the up and
// down arrow keys to scroll around.

Table tab;

// Keep track of which table row to show at the top of the screen.
// Use this to implement scrolling.
int start_row;

void setup()
{
  size( 800, 800 );
  start_row = 0;

  tab = loadTable( "haireyecolour.csv", "header" );

  fill( 255 );
  textSize( 24 );
}

void draw()
{
  background( 0 );

  // Draw the header row.
  fill( 255 );
  noStroke();
  rect( 0, 0, width, 40 );
  fill( 0 );

  for ( int jdx = 0; jdx < tab.getColumnCount(); ++jdx ) {
    String field_name = tab.getColumnTitle( jdx );
    text( field_name, 10 + jdx * 150, 10  + 24 );
  }

  // Draw the rest of the table.
  fill( 255 );
  for ( int idx = 0; idx < height/40 + 1; ++idx ) {
    if ( (idx + start_row) == tab.getRowCount() ) {
      break;
    }

    for ( int jdx = 0; jdx < tab.getColumnCount(); ++jdx ) {
      String cell = tab.getString( idx + start_row, jdx );
      text( cell, 10 + jdx * 150, 10 + (idx + 1) * 40 + 24 );
    }
  }
}

void keyPressed()
{
  if ( keyCode == DOWN ) {
    start_row ++;
    start_row = min(tab.getRowCount() - 1, start_row);
  } else if ( keyCode == UP ) {
    start_row = max( 0, start_row - 1 );
  }
}
