// Craig S. Kaplan
// 
// Using the Public Sector Salary Disclosure, find the ten highest-paid
// employees of the University of Waterloo.

// A helper function that removes all the punctuation from a string
// representing a salary, so that Processing can then turn it into
// an actual number.  Typical "working with real-world data" thing.
float stringToSalary( String sal )
{
  String digs = join( splitTokens( sal, "$,.-" ), "" );
  
  if ( digs.length() > 0 ) {
    return float(digs) / 100.0;
  } else {
    return 0;
  }
}

void setup()
{
  Table sals = loadTable( "pssd.csv", "header"  );
  // We want to keep track of salary + benefits as a number.  So 
  // *add a column* to the table, and store it there.
  sals.addColumn( "TotalSalary" );

  // Store all the total salary amounts in the new column in the table.
  for ( int idx = 0; idx < sals.getRowCount(); ++idx ) {
    float a = stringToSalary( sals.getString( idx, "Salary Paid" ) );
    float b = stringToSalary( sals.getString( idx, "Taxable Benefits" ) );

    sals.setFloat( idx, "TotalSalary", a + b );
  }

  // See the long comment in BaseballSalaries -- we need to
  // tell Processing to sort this column *as numbers*
  sals.setColumnType( "TotalSalary", Table.FLOAT );
  
  // Now sort, to bring all the top salaries to the front of
  // the table.
  sals.sortReverse( "TotalSalary" );

  int count = 0;
  int idx = 0;

  while ( count < 10 ) {
    //if ( sals.getString( idx, "Sector" ).equals( "Universities" ) ) {
   if ( sals.getString( idx, "Employer" ).equals( "University of Waterloo" ) ) {

      String fn = sals.getString( idx, "First Name" );
      String ln = sals.getString( idx, "Last Name" );
      String emp = sals.getString( idx, "Employer" );
      String pos = sals.getString( idx, "Job Title" );
      float sal = sals.getFloat( idx, "TotalSalary" );
      println( fn + " " + ln + " (" + pos + ", " + emp + ") -- " + sal );
      ++count;
    }
    ++idx;
  }
}